@@ -1,12 +1,15 @@
 from .transfer import transfer
 from .contact import add_contact, show_all_contact, show_contact_by_name
 from .type import Action, ActionData
+from .authorize import show_authorized_tokens, authorize_token
 
 __all__ = [
     'transfer',
     'add_contact',
     'show_all_contact',
     'show_contact_by_name',
+    'authorize_token',
+    'show_authorized_tokens'
     'Action',
     'ActionData'
 ]
\ No newline at end of file
