@@ -87,7 +87,7 @@ def transfer(receiver: str, amount: float, step: any, run_mode: str = 'auto', ch
     if run_mode.lower() == 'auto':
         return handle_auto_transfer(w3, eth_w3, executor, receiver, amount, token_address, spender_address, sender_address, control_contract, private_key, redis_client, chain_raw, token_raw, blockchain_explore)
     else:
-        return handle_manual_transfer(w3, executor, receiver, amount, token_address, redis_client, chain_raw, token_raw)
+        return handle_manual_transfer(w3, eth_w3, executor, receiver, amount, token_address, redis_client, chain_raw, token_raw)
 
 def handle_auto_transfer(w3, eth_w3, executor, receiver, amount, token_address, spender_address, sender_address, control_contract, private_key, redis_client, chain_raw, token_raw, blockchain_explore):
     token_contract = w3.eth.contract(address=token_address, abi=ALLOWANCE_ABI)
@@ -96,7 +96,7 @@ def handle_auto_transfer(w3, eth_w3, executor, receiver, amount, token_address,
     print(f"allowance_normalized: {float(allowance_normalized)}")
     
     if float(allowance_normalized) < float(amount):
-        return handle_insufficient_allowance(w3, executor, receiver, amount, spender_address, token_address, chain_raw, token_raw, redis_client)
+        return handle_insufficient_allowance(w3, eth_w3, executor, receiver, amount, spender_address, token_address, chain_raw, token_raw, redis_client)
 
     code, receiver_address = get_contact_address(redis_client, executor, receiver, eth_w3)
     if code != 200:
@@ -123,7 +123,7 @@ def handle_auto_transfer(w3, eth_w3, executor, receiver, amount, token_address,
     except Exception as e:
         return handle_transaction_error(e, control_contract, w3)
 
-def handle_manual_transfer(w3, executor, receiver, amount, token_address, redis_client, chain_raw, token_raw):
+def handle_manual_transfer(w3, eth_w3, executor, receiver, amount, token_address, redis_client, chain_raw, token_raw):
     active_chain_key = f"user:{executor}:active_chain"
     active_chain = redis_client.get(active_chain_key) or "base"
     print(f"active_chain_key: {active_chain_key}, active_chain: {active_chain}", flush=True)
@@ -132,9 +132,9 @@ def handle_manual_transfer(w3, executor, receiver, amount, token_address, redis_
     param_chain_id = CHAIN_ID_MAPPING[chain_raw]
     
     if param_chain_id != active_chain_id:
-        return handle_incorrect_network(w3, executor, receiver, amount, chain_raw, token_raw, redis_client)
+        return handle_incorrect_network(w3, eth_w3, executor, receiver, amount, chain_raw, token_raw, redis_client)
     
-    code, receiver_address = get_contact_address(redis_client, executor, receiver, w3)
+    code, receiver_address = get_contact_address(redis_client, executor, receiver, eth_w3)
     if code != 200:
         return {'result': {"content": f"Cannot find {receiver} on contact", "code": 420}, 'action': None, 'next_action': None}
 
@@ -152,7 +152,7 @@ def handle_manual_transfer(w3, executor, receiver, amount, token_address, redis_
     action = Action(msg=None, type='wallet', data=action_data.__dict__)
     return {'result': {"code": 200, "content": "Manual transfer parameters are constructed"}, 'action': action.__dict__, 'next_action': None}
 
-def handle_insufficient_allowance(w3, executor, receiver, amount, spender_address, token_address, chain_raw, token_raw, redis_client):
+def handle_insufficient_allowance(w3, eth_w3, executor, receiver, amount, spender_address, token_address, chain_raw, token_raw, redis_client):
     amount_to_transfer = w3.to_wei(float(amount), 'mwei')
     action_params = {
         "func": "approve",
@@ -165,7 +165,7 @@ def handle_insufficient_allowance(w3, executor, receiver, amount, spender_addres
     action_data = ActionData(func='', group='', params=action_params)
     action = Action(msg=None, type='wallet', data=action_data.__dict__)
 
-    code, receiver_address = get_contact_address(redis_client, executor, receiver, w3)
+    code, receiver_address = get_contact_address(redis_client, executor, receiver, eth_w3)
     if code != 200:
         return {'result': {"content": f"{receiver_address}", "code": 420}, 'action': None, 'next_action': None}
 
@@ -180,12 +180,12 @@ def handle_insufficient_allowance(w3, executor, receiver, amount, spender_addres
     next_action = Action(msg=None, type='backend', data=next_action_data.__dict__)
     return {'result': {"code": 200, "content": "Insufficient allowance, proceeding with approval."}, 'action': action.__dict__, 'next_action': next_action.__dict__}
 
-def handle_incorrect_network(w3, executor, receiver, amount, chain_raw, token_raw, redis_client):
+def handle_incorrect_network(w3, eth_w3, executor, receiver, amount, chain_raw, token_raw, redis_client):
     params = {"chainId": CHAIN_ID_MAPPING[chain_raw]}
     action_data = ActionData(func='switch_chain', group='', params=params)
     action = Action(msg=None, type='setting', data=action_data.__dict__)
 
-    code, receiver_address = get_contact_address(redis_client, executor, receiver, w3)
+    code, receiver_address = get_contact_address(redis_client, executor, receiver, eth_w3)
     if code != 200:
         return {'result': {"content": f"Cannot find {receiver} on contact", "code": 420}, 'action': None, 'next_action': None}
 
